cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting chr2:g.39417578C>G as the search term. The
  closest gene to the variant was found using MyVariant.info[1]. Gene expression
  in tumors for CDKL4 were queried from the Open Pediatric Cancer Atlas API[3].
  Median expression of CDKL4 was obtained from the GTEx Portal[4] using the
  portal's API. To visualize the level of expression across tumor gene
  expression, a bar plot was created Fig.. 

  1. Lelong, S. et al. BioThings SDK: a toolkit for building high-performance
  data APIs in biomedical research. Bioinformatics vol. 38 2077–2079 (2022).
  doi:10.1093/bioinformatics/btac017

  3. Shapiro, J. A. et al. OpenPBTA: The Open Pediatric Brain Tumor Atlas. Cell
  Genomics vol. 3 100340 (2023). doi:10.1016/j.xgen.2023.100340

  4. Lonsdale, J. et al. The Genotype-Tissue Expression (GTEx) project. Nature
  Genetics vol. 45 580–585 (2013). doi:10.1038/ng.2653
requirements: {}
inputs:
  step-1-data:
    label: Variant Input
    doc: Start with a Variant
    type: File
outputs:
  step-1-output:
    label: Variant
    doc: Variant Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Gene
    doc: Gene Term
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Tumor Gene Expression
    doc: Gene expression in tumors
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Scored Tissues
    doc: ZScores of Tissues
    type: File
    outputSource: step-4/output
  step-5-output:
    label: Plotly Plot
    doc: A plot rendered using the [plotly.js
      library](https://plotly.com/javascript/)
    type: File
    outputSource: step-5/output
steps:
  step-1:
    run: Input[Variant].cwl
    label: Variant Input
    doc: Start with a Variant
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: GeneTermFromVariantTerm.cwl
    label: Identify Closest Gene to Variant (Legacy)
    doc: Identify the closest gene to this variant
    in:
      inputs.variant:
        label: Variant
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: KFTumorExpressionFromGene.cwl
    label: Query KF Gene Expression in Tumor
    doc: Use KF API to obtain tumors expressing the given gene
    in:
      inputs.gene:
        label: Gene
        source: step-2/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: GTExTissueExpressionFromGene.cwl
    label: Query GTEx Median Tissue Expression
    doc: Use GTEx API to obtain median tissue expression for the given gene
    in:
      inputs.gene:
        label: Gene
        source: step-2/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: BarplotFrom[[TumorGeneExpression]].cwl
    label: Vertical bar plot from Tumor Gene Expression
    doc: Construct a vertical bar plot with Tumor Gene Expression
    in:
      inputs.other_terms:
        label: Scored Tissues
        source: step-4/output
      inputs.terms:
        label: Tumor Gene Expression
        source: step-3/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
